@@ -5,6 +5,15 @@
  * Get the library version.
  */
 
+/*
+ * added to support _WIN64
+ */
+#if _WIN64
+#define STRDUP _strdup
+#else
+#define STRDUP strdup
+#endif
+
 YAML_DECLARE(const char *)
 yaml_get_version_string(void)
 {
@@ -63,7 +72,7 @@ yaml_strdup(const yaml_char_t *str)
     if (!str)
         return NULL;
 
-    return (yaml_char_t *)strdup((char *)str);
+    return (yaml_char_t *) STRDUP((char *)str);
 }
 
 /*
@@ -1367,7 +1376,8 @@ yaml_document_append_mapping_pair(yaml_document_t *document,
     struct {
         yaml_error_type_t error;
     } context;
-    yaml_node_pair_t pair = { key, value };
+
+    yaml_node_pair_t pair;
 
     assert(document);       /* Non-NULL document is required. */
     assert(mapping > 0
@@ -1380,6 +1390,9 @@ yaml_document_append_mapping_pair(yaml_document_t *document,
     assert(value > 0 && document->nodes.start + value <= document->nodes.top);
                             /* Valid value id is required. */
 
+    pair.key = key;
+    pair.value = value;
+
     if (!PUSH(&context,
                 document->nodes.start[mapping-1].data.mapping.pairs, pair))
         return 0;
