@@ -22,6 +22,7 @@ import Data.Either.Compat
 import Test.Mockery.Directory
 
 import qualified Data.Yaml as D
+import qualified Data.Yaml.Pretty as Pretty
 import Data.Yaml (object, array, (.=))
 import Data.Maybe
 import qualified Data.HashMap.Strict as M
@@ -65,6 +66,10 @@ spec = do
         it "encode/decode strings" caseEncodeDecodeStrings
         it "decode invalid file" caseDecodeInvalid
         it "processes datatypes" caseDataTypes
+    describe "Data.Yaml.Pretty" $ do
+        it "encode/decode" caseEncodeDecodeDataPretty
+        it "encode/decode strings" caseEncodeDecodeStringsPretty
+        it "processes datatypes" caseDataTypesPretty
     describe "Data.Yaml aliases" $ do
         it "simple scalar alias" caseSimpleScalarAlias
         it "simple sequence alias" caseSimpleSequenceAlias
@@ -143,6 +148,8 @@ spec = do
     it "serialization of +123 #64" $ do
         D.decode (D.encode ("+123" :: String)) `shouldBe` Just ("+123" :: String)
 
+    it "preserves Scientific precision" casePreservesScientificPrecision
+
 
 specialStrings :: [T.Text]
 specialStrings =
@@ -299,6 +306,11 @@ caseEncodeDecodeData = do
     let out = D.decode $ D.encode sample
     out @?= Just sample
 
+caseEncodeDecodeDataPretty :: Assertion
+caseEncodeDecodeDataPretty = do
+    let out = D.decode $ Pretty.encodePretty Pretty.defConfig sample
+    out @?= Just sample
+
 caseEncodeDecodeFileData :: Assertion
 caseEncodeDecodeFileData = withFile "" $ \fp -> do
     D.encodeFile fp sample
@@ -310,6 +322,11 @@ caseEncodeDecodeStrings = do
     let out = D.decode $ D.encode sample
     out @?= Just sample
 
+caseEncodeDecodeStringsPretty :: Assertion
+caseEncodeDecodeStringsPretty = do
+    let out = D.decode $ Pretty.encodePretty Pretty.defConfig sample
+    out @?= Just sample
+
 caseDecodeInvalid :: Assertion
 caseDecodeInvalid = do
     let invalid = B8.pack "\tthis is 'not' valid :-)"
@@ -391,6 +408,18 @@ caseDataTypes =
         , ("null", D.Null)
         ]
 
+caseDataTypesPretty :: Assertion
+caseDataTypesPretty =
+    D.decode (Pretty.encodePretty Pretty.defConfig val) @?= Just val
+  where
+    val = object
+        [ ("string", D.String "foo")
+        , ("int", D.Number 5)
+        , ("float", D.Number 4.3)
+        , ("true", D.Bool True)
+        , ("false", D.Bool False)
+        , ("null", D.Null)
+        ]
 caseQuotedNumber, caseUnquotedNumber, caseAttribNumber, caseIntegerDecimals :: Assertion
 caseQuotedNumber = D.decode "foo: \"1234\"" @?= Just (object [("foo", D.String "1234")])
 caseUnquotedNumber = D.decode "foo: 1234" @?= Just (object [("foo", D.Number 1234)])
@@ -438,3 +467,20 @@ caseIssue49 =
         ])
   where
     src = "---\na:\n  &id5 value: 1.0\nb:\n  *id5: 1.2"
+
+-- | We cannot guarantee this before aeson started using 'Scientific'.
+casePreservesScientificPrecision :: Assertion
+casePreservesScientificPrecision = do
+    D.decodeEither "x: 1e-100000" @?= Right (object
+        [ "x" .= D.Number (read "1e-100000") ])
+    -- Note that this ought to work also without 'Scientific', given
+    -- that @read (show "9.78159610558926e-5") == 9.78159610558926e-5@.
+    -- However, it didn't work (and still doesn't work with aeson < 0.7)
+    -- for two reasons:
+    --
+    -- * We use 'Data.Text.Read.double', which is not as accurate as it
+    -- can be;
+    -- * Even if we used 'Data.Text.Read.rational' we would not get good
+    -- results, because of <https://github.com/bos/text/issues/34>.
+    D.decodeEither "x: 9.78159610558926e-5" @?= Right (object
+        [ "x" .= D.Number (read "9.78159610558926e-5") ])
